@@ -40,7 +40,7 @@ date_parser = re.compile(r"""^
                         \.
                         (?P<dec_second>\d+)?
                     )?
-                )?                                        
+                )?
                 (?:
                     Z
                     |
@@ -99,18 +99,20 @@ class CatWalk(turbogears.controllers.Controller):
     need_project = True
     icon = "/tg_static/images/catwalk.png"
 
-    def __init__(self,model=None):
-        """CatWalks initializer
-
-           @param model: reference to a project model module
-           @type model: yourproject.model 
+    def __init__(self, model=None):
         """
-         
+        CatWalks initializer
+
+        @param model: reference to a project model module
+        @type model: yourproject.model
+        """
+
         if model:
             self.model = model
         else:
             self.model = turbogears.util.get_model()
-        self.browse.catwalk = self 
+
+        self.browse.catwalk = self
 
         try:
             try:
@@ -122,7 +124,7 @@ class CatWalk(turbogears.controllers.Controller):
             traceback.print_exc(sys.exc_info())
             print """
                      CatWalk fail to load your model file,
-                     If you are mounting CatWalk to your controller remember 
+                     If you are mounting CatWalk to your controller remember
                      to import your model and pass a reference to it
                   """
         turbogears.config.update({'log_debug_info_filter.on':False})
@@ -134,34 +136,34 @@ class CatWalk(turbogears.controllers.Controller):
     error = turbogears.expose(format="json")(error)
 
     def load_object(self,object_name):
-        """Return a class reference from the models module by name 
-           
-           @param object_name: name of the object 
+        """Return a class reference from the models module by name
+
+           @param object_name: name of the object
            @type object_name: string
         """
         try:
             object = getattr(self.model,object_name)
-        except: 
+        except:
             msg='Fail to get reference to object %s'% object_name
             raise cherrypy.HTTPRedirect(turbogears.url('error', msg=msg))
         return object
 
     def load_instance(self,object_name,id):
         """Return and instance of the named object with the requested id"""
-        object = self.load_object(object_name)          
+        object = self.load_object(object_name)
         try:
-            return object.get(id)                    
+            return object.get(id)
         except:
             msg='Fail to get instance of object:%s with id:%s'% (object_name,id)
             raise cherrypy.HTTPRedirect(turbogears.url('error', msg=msg))
 
 
     def object_field(self,row,column):
-        """Return a dict containing the column name and value for 
+        """Return a dict containing the column name and value for
            the specific column and row
-           
+
            @param row: model instance
-           @param column: dict containing columnName, title, type, 
+           @param column: dict containing columnName, title, type,
                        eventually join, joinMethodName and/or options
            @type column: dict
         """
@@ -171,7 +173,7 @@ class CatWalk(turbogears.controllers.Controller):
                 value = '%s'% getattr(subject,column['labelColumn'])
             except:
                 return {'column':column['columnName'],'value':'None','id':'0'}
-            return {'column':column['columnName'],'value':value }           
+            return {'column':column['columnName'],'value':value }
         elif column.get('type','') in ('SORelatedJoin', 'SOSQLRelatedJoin'):
             return self.related_join_count(row,column)
         elif column.get('type','') in ('SOMultipleJoin', 'SOSQLMultipleJoin'):
@@ -187,16 +189,16 @@ class CatWalk(turbogears.controllers.Controller):
                 value = u'%s'% getattr(row,column['columnName'])
             except UnicodeDecodeError, e:
                 value = unicode( getattr(row,column['columnName']),'UTF-8')
-                
+
             return {'column':column['columnName'],'value':value }
-    
+
     def multiple_join_count(self,row,column):
         """Return the total number of related objects"""
         try:
             columnObject = getattr( self.model, column['join'] )
             for clm in columnObject.sqlmeta.columnList:
-                 if type(clm) == sqlobject.SOForeignKey:
-                     if column['objectName'] == clm.foreignKey: fk = clm
+                if type(clm) == sqlobject.SOForeignKey:
+                    if column['objectName'] == clm.foreignKey: fk = clm
             fkName = fk.name
             fkQuery = getattr( columnObject.q, str( fkName ) )
             select = columnObject.select( fkQuery == row.id)
@@ -220,18 +222,18 @@ class CatWalk(turbogears.controllers.Controller):
             value = getattr(name,column['labelColumn'])
             value = self.encode_label(value)
         except AttributeError:
-            return {'column':column['columnName'],'value':'None','id':'0'} 
+            return {'column':column['columnName'],'value':'None','id':'0'}
 
         return {'column':column['columnName'],
                 'value':value,
-                'id': '%s' % name.id 
+                'id': '%s' % name.id
                }
 
     def update_object(self,object_name,id,values):
-        object = self.load_object(object_name)          
+        object = self.load_object(object_name)
         instance = self.load_instance(object_name,id)
-        columns = self.object_columns(object_name)        
-        parameters = self.extract_parameters(columns,values)   
+        columns = self.object_columns(object_name)
+        parameters = self.extract_parameters(columns,values)
         instance.set(**parameters)
 
     def remove_related_joins_if_any(self,object_name,id):
@@ -239,7 +241,7 @@ class CatWalk(turbogears.controllers.Controller):
         object = self.load_object(object_name)
         instance = self.load_instance(object_name,id)
         for join in object.sqlmeta.joins:
-            if self.get_column_type(join) !='SORelatedJoin':continue 
+            if self.get_column_type(join) !='SORelatedJoin':continue
             for join_reference in list(getattr(instance,join.joinMethodName)):
                 method = self.uppercase_related_join_method(join.otherClassName,'remove')
                 getattr(instance,method)(join_reference)
@@ -257,17 +259,17 @@ class CatWalk(turbogears.controllers.Controller):
 
     def extract_parameters(self,cols,values):
         """Loop trough the columns and extract the values from the dictionary
-           
-           @param cols: column list 
-           @param values: dict of submited values 
+
+           @param cols: column list
+           @param values: dict of submited values
         """
         params = {}
         for col in cols:
             column_name = col['columnName']
-            if values.has_key(column_name): 
-                if col['type'] == 'SODateTimeCol': 
+            if values.has_key(column_name):
+                if col['type'] == 'SODateTimeCol':
                     dt = values[column_name]
-                    try: 
+                    try:
                         b = parse_datetime('%sZ'% dt.replace(' ','T'))
                     except: b  = None
                     values[column_name] = b
@@ -279,12 +281,12 @@ class CatWalk(turbogears.controllers.Controller):
 
                 if col['type'] == 'SOFloatCol':
                     try:b = float(values[column_name])
-                    except:b = 0.0 
+                    except:b = 0.0
                     values[column_name] = b
 
                 if col['type'] == 'SOIntCol':
                     try:b = int(values[column_name])
-                    except:b = 0 
+                    except:b = 0
                     values[column_name] = b
 
                 if col['type'] == 'SOForeignKey':
@@ -299,26 +301,26 @@ class CatWalk(turbogears.controllers.Controller):
 
     def extract_foreign_key(self,values,column_name):
         if values[column_name] =='__default_none__':
-            values[column_name]= None 
+            values[column_name]= None
         else:
             try:b = int(values[column_name])
-            except:b = 0 
+            except:b = 0
             values[column_name] = b
 
     def extract_decimal_value(self,values,column_name):
         try:
             import decimal
             try:b = decimal.Decimal(values[column_name])
-            except:b = decimal.Decimal('0.0') 
+            except:b = decimal.Decimal('0.0')
         except:
             try:b = float(values[column_name])
-            except:b = 0.0 
+            except:b = 0.0
         values[column_name] = b
 
     def object_instances(self,object_name,start=0):
         """return a dictionary containing all instances for the requested object
-           
-           @param object_name: name of the object 
+
+           @param object_name: name of the object
            @type object_name: string
         """
         obj = self.load_object(object_name)
@@ -346,7 +348,7 @@ class CatWalk(turbogears.controllers.Controller):
 
     def foreign_key_alternatives(self,foreign_key,column_label):
         """Return a list of dictionaries containing the posible foreignKey values
-           
+
            @param foreign_key: name of the foreignKey object
            @type foreign_key: string
            @param column_label: name of the column to use as instance identifier
@@ -365,16 +367,16 @@ class CatWalk(turbogears.controllers.Controller):
         except TypeError, e:
             return u'%s'% label  #this is an integer (fx. an id)
         except UnicodeEncodeError, e:
-            return u'%s'% label 
+            return u'%s'% label
 
     def headers_and_rows(self,objectName,rows):
         """Returns a tuple containing a list of rows and header labels
-           
-           @param objectName: name of the object 
+
+           @param objectName: name of the object
            @type objectName: string
-           @param rows: list of intances 
+           @param rows: list of intances
         """
-        cols = self.object_columns(objectName) 
+        cols = self.object_columns(objectName)
         labels = [{'column':col['columnName'],
                    'label':(col['title'] or col['columnName'])} for col in cols]
         labels.insert(0,{'column':'id','label':'ID'})
@@ -391,7 +393,7 @@ class CatWalk(turbogears.controllers.Controller):
     def object_joins(self,objectName,id,join,joinType,joinObjectName=''):
         """Collect the joined instances into a dictionary
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param id: id of the instance
            @type id: string
@@ -409,7 +411,7 @@ class CatWalk(turbogears.controllers.Controller):
         except:
             msg='Error, joins objectName: %s, id: %s, join: %s'% (objectName,id,join)
             raise cherrypy.HTTPRedirect(turbogears.url('error', msg=msg))
-        
+
         view = '%s_%s'% (hostObject,joinObjectName)
         hidden_columns = self.load_columns_visibility_state(view)
 
@@ -428,7 +430,7 @@ class CatWalk(turbogears.controllers.Controller):
         c = '%s'% rows[0].sqlmeta.soClass
         objectName= c.split('.')[-1].replace("'>",'')
         headers, rows = self.headers_and_rows(objectName,rows)
-        joinsDict['objectName'] = objectName 
+        joinsDict['objectName'] = objectName
         joinsDict['rows'] = rows
         joinsDict['headers'] = headers
         return joinsDict
@@ -447,7 +449,7 @@ class CatWalk(turbogears.controllers.Controller):
 
     def column_title(self,column):
         if isinstance(column, sqlobject.col.SOForeignKey):
-            return column.name.replace('ID','') 
+            return column.name.replace('ID','')
 
         try: title =( getattr(column,'title') or '')
         except AttributeError: title =''
@@ -468,16 +470,16 @@ class CatWalk(turbogears.controllers.Controller):
             return ':'.join( d.split(':')[:-1] )
         if column_type == 'SODateCol':
             d = '%s'% default
-            return d.split()[0] 
+            return d.split()[0]
         return ''
 
     def get_column_properties(self,column_name,column):
         """Return a dictionary containing the column properties
            Depending on the column type the properties returned could be:
-           type, title, join (otherClassName), joinMethodName, 
+           type, title, join (otherClassName), joinMethodName,
            length, varchar,labelColumn,opetions
 
-           @param column_name: name of the column 
+           @param column_name: name of the column
            @type column_name: string
            @param column: column instance
         """
@@ -485,7 +487,7 @@ class CatWalk(turbogears.controllers.Controller):
         props['title'] = self.column_title(column)
         props['default'] = self.column_default(column,props['type'])
 
-        if props['type'] == 'SOEnumCol': 
+        if props['type'] == 'SOEnumCol':
             props['options'] = column.enumValues
         if props['type'] in ('SOMultipleJoin', 'SOSQLMultipleJoin',
           'SORelatedJoin', 'SOSQLRelatedJoin'):
@@ -497,13 +499,13 @@ class CatWalk(turbogears.controllers.Controller):
             props['labelColumn'] = self.load_label_column_for_object(column.otherClassName)
             props['options'] = self.foreign_key_alternatives(column.otherClassName,
                                                                 props['labelColumn'])
-	    props['objectName'] = column.soClass.__name__
+        props['objectName'] = column.soClass.__name__
         if props['type'] in ['SOStringCol','SOUnicodeCol']:
             props = self.get_string_properties(column,props)
         if props['type'] == 'SOForeignKey':
             props = self.get_foreign_key_properties(column,props)
         return props
-    
+
     def get_string_properties(self,column,properties):
         """Extract the SOStringCol properties from the column object"""
         properties['length'] = column.length
@@ -513,7 +515,7 @@ class CatWalk(turbogears.controllers.Controller):
     def get_foreign_key_properties(self,column,properties):
         """Extract the foreignKey properties from the column object"""
         properties['join'] = column.foreignKey
-        properties['columnName'] = column.foreignName 
+        properties['columnName'] = column.foreignName
         properties['labelColumn'] = self.load_label_column_for_object(column.foreignKey)
         properties['options'] = self.foreign_key_alternatives(column.foreignKey,
                                                                properties['labelColumn'])
@@ -522,28 +524,28 @@ class CatWalk(turbogears.controllers.Controller):
         return properties
 
     def object_columns(self,object_name):
-        """Return list of columns properties arranged in dicts 
-           @param object_name: name of the object 
+        """Return list of columns properties arranged in dicts
+           @param object_name: name of the object
            @type object_name: string
         """
-        object = self.load_object(object_name)          
+        object = self.load_object(object_name)
         cols = self.get_columns_for_object(object)
         return self.order_columns(object_name,cols)
-    
+
     def get_columns_for_object(self,object):
-        """Return list of columns properties arranged in dicts 
-           @param object: model instance 
+        """Return list of columns properties arranged in dicts
+           @param object: model instance
         """
         cols = []
         """get normal columns"""
         for column_name in object.sqlmeta.columns:
             column = object.sqlmeta.columns[column_name]
             if object._inheritable and column_name == 'childName':continue
-            cols.append(self.get_column_properties(column_name,column)) 
+            cols.append(self.get_column_properties(column_name,column))
 
         """get join columns"""
         for column in object.sqlmeta.joins:
-            cols.append(self.get_column_properties(column.joinMethodName,column)) 
+            cols.append(self.get_column_properties(column.joinMethodName,column))
 
         """get inherited columns"""
         if object._inheritable and not self.is_inheritable_base_class(object):
@@ -562,7 +564,7 @@ class CatWalk(turbogears.controllers.Controller):
     """ ===================== CONFIGURATION STATE ============================"""
     def state_path(self):
         """Return the path to the catwalk session pickle -create a session directory if nescesary"""
-        catwalk_session_dir = os.path.join(turbogears.util.get_package_name(),'catwalk-session')
+        catwalk_session_dir = os.path.join(turbogears.util.get_package_name() or '','catwalk-session')
         catwalk_session_dir = os.path.abspath( catwalk_session_dir )
         if not os.path.exists(catwalk_session_dir):
             try:
@@ -591,7 +593,7 @@ class CatWalk(turbogears.controllers.Controller):
 
     def hide_columns(self,view,columns=''):
         state = self.load_state()
-        hidden_columns = state.get('hidden_columns',{})    
+        hidden_columns = state.get('hidden_columns',{})
         hidden_columns[view] =columns.split('|')
         print '*'*80
         print hidden_columns
@@ -600,24 +602,25 @@ class CatWalk(turbogears.controllers.Controller):
         self.save_state(state)
 
     def toggle_columns_visibility_state(self,view,columns):
-        """Toggle the columns visibility and store the new state 
-           @param view: name of the grid view to be stored 
+        """Toggle the columns visibility and store the new state
+           @param view: name of the grid view to be stored
            @type view: string
            @param columns: name of the columns to be hidden or shown
            @type column: bar separated string
         """
         state = self.load_state()
-        hidden_columns = state.get('hidden_columns',{})    
+        hidden_columns = state.get('hidden_columns',{})
         if not columns:
             hidden_columns[view] = []
             hidden_columns_list = []
         else:
-            hidden_columns_list = hidden_columns.get(view,[])    
+            hidden_columns_list = hidden_columns.get(view,[])
             columns = columns.split('|')
             for column in columns:
 
-                if column in hidden_columns_list: 
-                    hidden_columns_list = [x for x in hidden_columns_list if x !=column]
+                if column in hidden_columns_list:
+                    hidden_columns_list = [x for x in hidden_columns_list
+                      if x != column]
                 else:
                     hidden_columns_list.append(column)
 
@@ -629,35 +632,35 @@ class CatWalk(turbogears.controllers.Controller):
         """Return a list of columns names for the requested view that should
            not be shown
 
-           @param view: name of the grid view to be stored 
+           @param view: name of the grid view to be stored
            @type view: string
         """
         state = self.load_state()
-        hidden_columns = state.get('hidden_columns',{})    
-        return hidden_columns.get(view,[])    
+        hidden_columns = state.get('hidden_columns',{})
+        return hidden_columns.get(view,[])
 
     def load_label_column_for_object(self,objectName):
         """Return the column name to be used as foreignKey label for the
            requested object
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
         """
         state = self.load_state()
-        lables = state.get('columns',{})    
+        lables = state.get('columns',{})
         return lables.get(objectName,'id')
 
     def column_label_for_object(self,objectName,columnName):
-        """Store the column name to be used as foreignKey label for the 
+        """Store the column name to be used as foreignKey label for the
            requested object
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param columnName: name of the column to use as foreignKey label
            @type columnName: string
         """
         state = self.load_state()
-        cl= state.get('columns',{})    
+        cl= state.get('columns',{})
         cl[objectName] = columnName
         state['columns'] = cl
         self.save_state(state)
@@ -665,24 +668,24 @@ class CatWalk(turbogears.controllers.Controller):
     def load_column_order(self,object_name):
         """If the user has rearrenged the columns order for an object,
            this will return the prefered order as list
-           
-           @param object_name: name of the object 
+
+           @param object_name: name of the object
            @type object_name: string
         """
         state = self.load_state()
-        cols = state.get('order',{})    
+        cols = state.get('order',{})
         return cols.get(object_name,[])
 
     def save_column_order(self,object_name,columns_bsv):
         """Save the prefered order of the object's columns
 
-           @param object_name: name of the object 
+           @param object_name: name of the object
            @type object_name: string
            @param columns_bsv: bar (|) delimited columns names
            @type columns_bsv: string
         """
         state = self.load_state()
-        cl= state.get('order',{})    
+        cl= state.get('order',{})
         cl[object_name] = columns_bsv.split('|')
         state['order'] = cl
         self.save_state(state)
@@ -690,9 +693,9 @@ class CatWalk(turbogears.controllers.Controller):
     def order_columns(self,object_name,cols):
         """Return a rearrenged list of columns as configured by the user
 
-           @param object_name: name of the object 
+           @param object_name: name of the object
            @type object_name: string
-           @param cols: original list of columns following the default table order 
+           @param cols: original list of columns following the default table order
            @type cols: list
         """
         order = self.load_column_order(object_name)
@@ -715,7 +718,7 @@ class CatWalk(turbogears.controllers.Controller):
 
     def load_models_order(self):
         state = self.load_state()
-        return state.get('model_order',[])    
+        return state.get('model_order',[])
 
     def order_models(self,models):
         ordered = self.load_models_order()
@@ -732,7 +735,7 @@ class CatWalk(turbogears.controllers.Controller):
     """====================== EXPOSED METHODS =============================="""
     def add(self,**v):
         """Create a new instance of an object
-            
+
            @param v: dictionary of submited values
         """
         objectName = v['objectName']
@@ -754,7 +757,7 @@ class CatWalk(turbogears.controllers.Controller):
 
     def update(self,**values):
         """Update the objects properties
-           
+
            @param values: dictionary of key and values, as a bare minimum
                      the name of the object (objectName) and the id
         """
@@ -771,10 +774,10 @@ class CatWalk(turbogears.controllers.Controller):
     update = turbogears.expose(format="json")(update)
 
     def remove(self,objectName,id):
-        """Remove and instance by id 
+        """Remove and instance by id
            This doesn't handle references (cascade delete)
-           
-           @param objectName: name of the object 
+
+           @param objectName: name of the object
            @type objectName: string
            @param id: id of the instance to be removed
            @type id: string
@@ -790,14 +793,14 @@ class CatWalk(turbogears.controllers.Controller):
     remove = turbogears.expose(format="json")(remove)
 
     def remove_single_join(self,object_name,id,join_object_name,join_object_id):
-        """Remove a single join instance by id 
+        """Remove a single join instance by id
            This doesn't handle references (cascade delete)
-           
-           @param object_name: name of the host object 
+
+           @param object_name: name of the host object
            @type object_name: string
-           @param id: id of the host instance 
+           @param id: id of the host instance
            @type id: string
-           @param join_object_name: name of the join object 
+           @param join_object_name: name of the join object
            @type join_object_name: string
            @param join_object_id: id of the join instance to be removed
            @type join_object_id: string
@@ -806,7 +809,7 @@ class CatWalk(turbogears.controllers.Controller):
         return self.object_instance(object_name,id)
     remove_single_join = turbogears.expose(format="json")(remove_single_join)
 
-    def saveModelOrder(self,models): 
+    def saveModelOrder(self,models):
         """Save the prefered order of the listed models"""
         self.save_model_order(models)
         return '' #return dummy string, else json will barf
@@ -815,30 +818,30 @@ class CatWalk(turbogears.controllers.Controller):
     def columnOrder(self,objectName,cols):
         """Save the prefered order of the object's columns
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
-           @param cols: columns names separated by '|' 
+           @param cols: columns names separated by '|'
            @type cols: string
         """
         self.save_column_order(objectName,cols)
         """return dummy string, else json will barf"""
-        return '' 
+        return ''
     columnOrder = turbogears.expose(format="json")(columnOrder)
-    
+
     def instances(self,objectName,start=0):
         """Return a JSON structure containing all instances of the requested object
-           
-           @param objectName: name of the object 
+
+           @param objectName: name of the object
            @type objectName: string
         """
         return self.object_instances(objectName,start)
     instances = turbogears.expose(format="json")(instances)
 
     def manageRelatedJoins(self,objectName,id,join,relatedObjectName,**vargs):
-        """Return a JSON structure whith a list of related joins for 
+        """Return a JSON structure whith a list of related joins for
            the requested object, and a list of all joins
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param id: id of the instance
            @type id: string
@@ -852,12 +855,12 @@ class CatWalk(turbogears.controllers.Controller):
         joins['allJoins'] = self.object_instances(relatedObjectName)
         return joins
     manageRelatedJoins = turbogears.expose(format="json")(manageRelatedJoins)
-   
+
     def updateJoins(self,objectName,id,join,joinType,joinObjectName,joins):
         """Drop all related joins first, then loop trought the submited joins
            and set the relation
-           
-           @param objectName: name of the object 
+
+           @param objectName: name of the object
            @type objectName: string
            @param id: id of the instance to be removed
            @type id: string
@@ -873,12 +876,12 @@ class CatWalk(turbogears.controllers.Controller):
         try:
             obj = self.load_object(objectName)
             inst = obj.get(id)
-            
+
             # get the add/remove method names
             j = [j for j in obj.sqlmeta.joins if (j.joinMethodName == join)][0]
             remove_method = getattr(inst, 'remove' +  j.addRemoveName)
- 	    add_method = getattr(inst, 'add' + j.addRemoveName)
- 	    
+            add_method = getattr(inst, 'add' + j.addRemoveName)
+
             # remove all joined instances
             for joined_instance in list(getattr(inst, join)):
                 remove_method(joined_instance)
@@ -887,23 +890,23 @@ class CatWalk(turbogears.controllers.Controller):
             join_object = self.load_object(joinObjectName)
             joins = joins.split(',')
             for i in joins:
-                try: i=int(i) 
+                try: i=int(i)
                 except: continue
                 instance = join_object.get(i)
                 add_method(instance)
         except Exception, e:
             cherrypy.response.status = 500
             return dict(error=str(e))
-        returnlist = self.object_instance(objectName,id); 
+        returnlist = self.object_instance(objectName,id);
         returnlist["msg"] = "The object was successfully updated"
         return returnlist
 
     updateJoins = turbogears.expose(format="json")(updateJoins)
 
     def updateColumns(self,objectName,column):
-        """Toggle (and store) the state of the requested column in grid view display. 
-           
-           @param objectName: name of the object 
+        """Toggle (and store) the state of the requested column in grid view display.
+
+           @param objectName: name of the object
            @type objectName: string
            @param column: name of the column to be hidden
            @type column: string
@@ -913,12 +916,12 @@ class CatWalk(turbogears.controllers.Controller):
     updateColumns = turbogears.expose(format="json")(updateColumns)
 
     def updateColumnsJoinView(self,objectName,id,join,joinType,joinObjectName,column):
-        """Toggle (and store) the state of the requested column 
-           in grid view display for a join view. 
-           
-           @param objectName: name of the object 
+        """Toggle (and store) the state of the requested column
+           in grid view display for a join view.
+
+           @param objectName: name of the object
            @type objectName: string
-           @param id: id of the 'parent' instance 
+           @param id: id of the 'parent' instance
            @type id: string
            @param join: name of the join (joinMethodName in SQLObject parlance)
            @type join: string
@@ -934,10 +937,10 @@ class CatWalk(turbogears.controllers.Controller):
     updateColumnsJoinView = turbogears.expose(format="json")(updateColumnsJoinView)
 
     def joins(self,objectName,id,join,joinType,joinObjectName):
-        """Return a JSON structure containing a list joins for 
+        """Return a JSON structure containing a list joins for
            the requested object's joinMethodName
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param id: id of the instance
            @type id: string
@@ -950,7 +953,7 @@ class CatWalk(turbogears.controllers.Controller):
         """
         return self.object_joins(objectName,id,join,joinType,joinObjectName)
     joins = turbogears.expose(format="json")(joins)
-    
+
     def object_instance(self,object_name,id):
         obj = self.load_object(object_name)
         inst = obj.get(id)
@@ -989,14 +992,14 @@ class CatWalk(turbogears.controllers.Controller):
                 col['id'] = self.object_field(inst,colForID)
                 col['value'] = self.object_field(inst,col)
             col['objectName'] = object_name
-            values.append(col) 
+            values.append(col)
         return dict(objectName=object_name,id=id,values=values)
 
     def instance(self,objectName,id):
         """Return a JSON structure containing the columns and field values for
            the requested object
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param id: id of the instance
            @type id: string
@@ -1007,29 +1010,29 @@ class CatWalk(turbogears.controllers.Controller):
     def columnsForLabel(self,objectName,foreignObjectName,foreignKeyName):
         """Return a JSON structure with a list of columns to use as foreignKey label
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param foreignObjectName: name of the object the foreignKey refers to
            @type foreignObjectName: string
            @param foreignKeyName: name of the object foreignKey field
            @type foreignKeyName: string
         """
-        cols = [{'columnName':col['columnName'],'title':col['title']}    
-                        for col in self.object_columns(foreignObjectName) 
-                        if col['type'] !='SOMultipleJoin' 
+        cols = [{'columnName':col['columnName'],'title':col['title']}
+                        for col in self.object_columns(foreignObjectName)
+                        if col['type'] !='SOMultipleJoin'
                      ]
         return dict(columns=cols,
                     foreignKeyName=foreignKeyName,
-                    foreignKeyColumnForLabel= self.load_label_column_for_object(foreignObjectName), 
+                    foreignKeyColumnForLabel= self.load_label_column_for_object(foreignObjectName),
                     foreignObjectName=foreignObjectName,
                     objectName=objectName)
     columnsForLabel = turbogears.expose(format="json")(columnsForLabel)
 
     def setColumnForLabel(self,objectName,foreignObjectName,foreignKeyName,columnName):
-        """Exposed method that let you store the column name to be used as 
+        """Exposed method that let you store the column name to be used as
            foreignKey label for the requested object
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
            @param foreignObjectName: name of the object the foreignKey refers to
            @type foreignObjectName: string
@@ -1045,7 +1048,7 @@ class CatWalk(turbogears.controllers.Controller):
     def columns(self,objectName,**kv):
         """Return JSON structure containing a list of column properties
 
-           @param objectName: name of the object 
+           @param objectName: name of the object
            @type objectName: string
         """
         reorder = not kv.has_key('foreignObjectName')
@@ -1077,7 +1080,7 @@ class CatWalk(turbogears.controllers.Controller):
 
     def register_static_directory(self):
         static_directory = pkg_resources.resource_filename(__name__,'static')
-        turbogears.config.update( 
+        turbogears.config.update(
                                 { '/tg_toolbox/catwalk': {
                                                             'static_filter.on':True,
                                                             'static_filter.dir':static_directory
